/**
 * Service for streetview functionality with Mapillary
 */
declare class MapillaryService extends StreetviewService {
    /**
     * @param {angular.IScope} $scope Angular Scope.
     * @param {angular.ITimeoutService} $timeout Angular $timeout.
     * @param {angular.IHttpService} $http Angular $http service.
     * @param {?import('ol/Map').default} map The map.
     * @param {(newCoordinates: import('ol/coordinate').Coordinate | null) => void} handlePanoramaPositionChange Position change handler.
     * @param {string} accessToken The key to access the mapillary api.
     * @param {number} bufferSize The size to add to the bbox buffer.
     */
    constructor($scope: angular.IScope, $timeout: angular.ITimeoutService, $http: angular.IHttpService, map: import("ol/Map").default | null, handlePanoramaPositionChange: (newCoordinates: import("ol/coordinate").Coordinate | null) => void, accessToken: string, bufferSize: number);
    /**
     * @type {angular.ITimeoutService}
     * @private
     */
    private $timeout_;
    /**
     * Angular $http service.
     *
     * @private
     */
    private $http_;
    /**
     * The key to access the mapillary api.
     *
     * @private
     */
    private accessToken_;
    /**
     * The size of the buffer (in pixel) to add to the coordinate points to create the request bbox.
     *
     * @private
     */
    private bufferSizePx_;
    /**
     * Container of the mapillary viewer.
     */
    mapillaryElement: HTMLElement;
    Mapillary: {
        default: typeof import("mapillary-js");
        Alignment: typeof import("mapillary-js").Alignment;
        ArgumentMapillaryError: typeof import("mapillary-js").ArgumentMapillaryError;
        BearingComponent: typeof import("mapillary-js").BearingComponent;
        CacheComponent: typeof import("mapillary-js").CacheComponent;
        CameraControls: typeof import("mapillary-js").CameraControls;
        CameraVisualizationMode: typeof import("mapillary-js").CameraVisualizationMode;
        CancelMapillaryError: typeof import("mapillary-js").CancelMapillaryError;
        CircleMarker: typeof import("mapillary-js").CircleMarker;
        Component: typeof import("mapillary-js").Component;
        ComponentSize: typeof import("mapillary-js").ComponentSize;
        DataProviderBase: typeof import("mapillary-js").DataProviderBase;
        DirectionComponent: typeof import("mapillary-js").DirectionComponent;
        DragPanHandler: typeof import("mapillary-js").DragPanHandler;
        EventEmitter: typeof import("mapillary-js").EventEmitter;
        ExtremePointTag: typeof import("mapillary-js").ExtremePointTag;
        Geometry: typeof import("mapillary-js").Geometry;
        GeometryProviderBase: typeof import("mapillary-js").GeometryProviderBase;
        GeometryTagError: typeof import("mapillary-js").GeometryTagError;
        GraphDataProvider: typeof import("mapillary-js").GraphDataProvider;
        GraphMapillaryError: typeof import("mapillary-js").GraphMapillaryError;
        Image: typeof import("mapillary-js").Image;
        KeyPlayHandler: typeof import("mapillary-js").KeyPlayHandler;
        KeySequenceNavigationHandler: typeof import("mapillary-js").KeySequenceNavigationHandler;
        KeySpatialNavigationHandler: typeof import("mapillary-js").KeySpatialNavigationHandler;
        KeyZoomHandler: typeof import("mapillary-js").KeyZoomHandler;
        KeyboardComponent: typeof import("mapillary-js").KeyboardComponent;
        MapillaryError: typeof import("mapillary-js").MapillaryError;
        Marker: typeof import("mapillary-js").Marker;
        MarkerComponent: typeof import("mapillary-js").MarkerComponent;
        NavigationDirection: typeof import("mapillary-js").NavigationDirection;
        OriginalPositionMode: typeof import("mapillary-js").OriginalPositionMode;
        OutlineTag: typeof import("mapillary-js").OutlineTag;
        PointGeometry: typeof import("mapillary-js").PointGeometry;
        PointVisualizationMode: typeof import("mapillary-js").PointVisualizationMode;
        PointerComponent: typeof import("mapillary-js").PointerComponent;
        PointsGeometry: typeof import("mapillary-js").PointsGeometry;
        PolygonGeometry: typeof import("mapillary-js").PolygonGeometry;
        Popup: typeof import("mapillary-js").Popup;
        PopupComponent: typeof import("mapillary-js").PopupComponent;
        RectGeometry: typeof import("mapillary-js").RectGeometry;
        RenderMode: typeof import("mapillary-js").RenderMode;
        RenderPass: typeof import("mapillary-js").RenderPass;
        S2GeometryProvider: typeof import("mapillary-js").S2GeometryProvider;
        ScrollZoomHandler: typeof import("mapillary-js").ScrollZoomHandler;
        SequenceComponent: typeof import("mapillary-js").SequenceComponent;
        SimpleMarker: typeof import("mapillary-js").SimpleMarker;
        SliderComponent: typeof import("mapillary-js").SliderComponent;
        SliderConfigurationMode: typeof import("mapillary-js").SliderConfigurationMode;
        SpatialComponent: typeof import("mapillary-js").SpatialComponent;
        SpotTag: typeof import("mapillary-js").SpotTag;
        Tag: typeof import("mapillary-js").Tag;
        TagComponent: typeof import("mapillary-js").TagComponent;
        TagDomain: typeof import("mapillary-js").TagDomain;
        TagMode: typeof import("mapillary-js").TagMode;
        TouchZoomHandler: typeof import("mapillary-js").TouchZoomHandler;
        TransitionMode: typeof import("mapillary-js").TransitionMode;
        VertexGeometry: typeof import("mapillary-js").VertexGeometry;
        Viewer: typeof import("mapillary-js").Viewer;
        ZoomComponent: typeof import("mapillary-js").ZoomComponent;
        decompress: typeof import("mapillary-js").decompress;
        ecefToEnu: typeof import("mapillary-js").ecefToEnu;
        ecefToGeodetic: typeof import("mapillary-js").ecefToGeodetic;
        enuToEcef: typeof import("mapillary-js").enuToEcef;
        enuToGeodetic: typeof import("mapillary-js").enuToGeodetic;
        fetchArrayBuffer: typeof import("mapillary-js").fetchArrayBuffer;
        geodeticToEcef: typeof import("mapillary-js").geodeticToEcef;
        geodeticToEnu: typeof import("mapillary-js").geodeticToEnu;
        isFallbackSupported: typeof import("mapillary-js").isFallbackSupported;
        isSupported: typeof import("mapillary-js").isSupported;
        readMeshPbf: typeof import("mapillary-js").readMeshPbf;
    };
    mly: import("mapillary-js").Viewer;
    /**
     * @param {import('mapillary-js/src/viewer/events/ViewerImageEvent').ViewerImageEvent} evt
     */
    mapillaryEventHandler_: (evt: import("mapillary-js/src/viewer/events/ViewerImageEvent").ViewerImageEvent) => void;
    /**
     * Resize the image.
     */
    resize(): void;
    /**
     * @param {import("ol/extent.js").Extent} bbox A bounding box in LatLong projection
     * @returns {angular.IPromise<string>} Promise with the first imageId found or null.
     * @private
     */
    private searchImage_;
}
declare namespace MapillaryService {
    let $inject: string[];
}
export default MapillaryService;
import { StreetviewService } from './Service';
